from datetime import time

from pydantic import BaseModel


class MovieBaseSchema(BaseModel):
    name: str | None = None
    year: int | None = None
    country: str | None = None


class MovieIdSchema(BaseModel):
    id: int

    class Config:
        from_attributes = True


class MovieListSchema(MovieBaseSchema, MovieIdSchema):
    pass


class MovieGetSchema(MovieBaseSchema, MovieIdSchema):
    director: int
    genre: int
    description: str
    duration: time


class MoviePostSchema(MovieBaseSchema):
    director: int
    genre: int
    description: str
    duration: time


class MoviePatchSchema(MovieBaseSchema):
    director: int | None = None
    genre: int | None = None
    description: str | None = None
    duration: time | None = None
